Deal with $hostname and $shorthost
[apps/madmutt.git] / sendlib.c
index 2c9b534..1802e1d 100644 (file)
--- a/sendlib.c
+++ b/sendlib.c
@@ -12,6 +12,7 @@
 #include <signal.h>
 #include <sys/utsname.h>
 
+#include <lib-lua/lib-lua.h>
 #include <lib-sys/exit.h>
 #include <lib-sys/mutt_signal.h>
 #include <lib-mime/mime.h>
@@ -766,10 +767,10 @@ CONTENT *mutt_get_content_info (const char *fname, BODY * b)
 
   if (b != NULL && b->type == TYPETEXT && (!b->noconv && !b->force_charset)) {
     const char *chs = parameter_getval(b->parameter, "charset");
-    char *fchs = b->use_disp ? ((FileCharset && *FileCharset) ?
-                                FileCharset : Charset) : Charset;
-    if (Charset && (chs || SendCharset) &&
-        convert_file_from_to (fp, fchs, chs ? chs : SendCharset,
+    char *fchs = b->use_disp && !m_strisempty(MCharset.file_charset)
+        ? FileCharset : MCharset.charset;
+    if (MCharset.charset && (chs || MCharset.send_charset) &&
+        convert_file_from_to (fp, fchs, chs ? chs : MCharset.send_charset,
                               &fromcode, &tocode, info) != -1) {
       if (!chs) {
         charset_canonicalize (chsbuf, sizeof (chsbuf), tocode);
@@ -792,7 +793,8 @@ CONTENT *mutt_get_content_info (const char *fname, BODY * b)
   if (b != NULL && b->type == TYPETEXT && (!b->noconv && !b->force_charset))
     parameter_setval(&b->parameter, "charset",
                      (!info->hibin ? "us-ascii"
-                      : Charset && !charset_is_us_ascii(Charset) ? Charset : "unknown-8bit"));
+                      : MCharset.charset && !charset_is_us_ascii(MCharset.charset)
+                                         ? MCharset.charset : "unknown-8bit"));
 
   return info;
 }
@@ -828,7 +830,7 @@ int mutt_lookup_mime_type (BODY * att, const char *path)
      */
     switch (count) {
     case 0:
-      snprintf (buf, sizeof (buf), "%s/.mime.types", NONULL (Homedir));
+      snprintf(buf, sizeof (buf), "%s/.mime.types", NONULL(MCore.homedir));
       break;
     case 1:
       m_strcpy(buf, sizeof(buf), SYSCONFDIR "/madmutt-mime.types");
@@ -924,7 +926,7 @@ void mutt_message_to_7bit (BODY * a, FILE * fp)
     a->length = sb.st_size;
   }
 
-  fpout = m_tempfile(temp, sizeof(temp), NONULL(Tempdir), NULL);
+  fpout = m_tempfile(temp, sizeof(temp), NONULL(MCore.tmpdir), NULL);
   if (!fpout) {
     mutt_error(_("Could not create temporary file"));
     goto cleanup;
@@ -989,7 +991,7 @@ static void transform_to_7bit (BODY * a, FILE * fpin)
       a->noconv = 1;
       a->force_charset = 1;
 
-      s.fpout = m_tempfile(buff, sizeof(buff), NONULL(Tempdir), NULL);
+      s.fpout = m_tempfile(buff, sizeof(buff), NONULL(MCore.tmpdir), NULL);
       if (!s.fpout) {
         mutt_error(_("Could not create temporary file"));
         return;
@@ -1113,7 +1115,7 @@ BODY *mutt_make_message_attach (CONTEXT * ctx, HEADER * hdr, int attach_msg)
       return (NULL);
   }
 
-  fp = m_tempfile(buffer, sizeof(buffer), NONULL(Tempdir), NULL);
+  fp = m_tempfile(buffer, sizeof(buffer), NONULL(MCore.tmpdir), NULL);
   if (!fp)
     return NULL;
 
@@ -1505,7 +1507,7 @@ int mutt_write_rfc822_header (FILE * fp, ENVELOPE * env, BODY * attach,
       os = (uname(&un) == -1) ? "UNIX" : un.sysname;
     }
     /* Add a vanity header */
-    fprintf (fp, "User-Agent: %s (%s)\n", mutt_make_version (0), os);
+    fprintf (fp, "User-Agent: %s (%s)\n", mutt_make_version(), os);
   }
 
   return (ferror (fp) == 0 ? 0 : -1);
@@ -1537,22 +1539,22 @@ static void encode_headers (string_list_t * h)
   }
 }
 
-const char *mutt_fqdn (short may_hide_host)
+const char *mutt_fqdn(short may_hide_host)
 {
   char *p = NULL, *q;
 
-  if (Fqdn && Fqdn[0] != '@') {
-    p = Fqdn;
+  if (MCore.hostname && MCore.hostname[0] != '@') {
+    p = MCore.hostname;
 
     if (may_hide_host && option (OPTHIDDENHOST)) {
-      if ((p = strchr (Fqdn, '.')))
+      if ((p = strchr(MCore.hostname, '.')))
         p++;
 
       /* sanity check: don't hide the host if
          the fqdn is something like detebe.org.  */
 
-      if (!p || !(q = strchr (p, '.')))
-        p = Fqdn;
+      if (!p || !(q = strchr(p, '.')))
+        p = MCore.hostname;
     }
   }
 
@@ -1655,7 +1657,7 @@ static char *mutt_gen_msgid (void)
     const char *fqdn;
 
     if (!(fqdn = mutt_fqdn(0)))
-        fqdn = NONULL(Hostname);
+        fqdn = NONULL(MCore.shorthost);
 
     mutt_gen_localpart(localpart, sizeof(localpart), MsgIdFormat);
     snprintf(buf, sizeof(buf), "<%s@%s>", localpart, fqdn);
@@ -1688,7 +1690,7 @@ send_msg(const char *path, const char **args, const char *msg, char **tempfile)
   sigaddset (&set, SIGTSTP);
   sigprocmask (SIG_BLOCK, &set, NULL);
 
-  if (SendmailWait >= 0) {
+  if (MTransport.sendmail_wait >= 0) {
     char tmp[_POSIX_PATH_MAX];
 
     mutt_mktemp (tmp);
@@ -1719,7 +1721,7 @@ send_msg(const char *path, const char **args, const char *msg, char **tempfile)
       }
       unlink (msg);
 
-      if (SendmailWait >= 0) {
+      if (MTransport.sendmail_wait >= 0) {
         /* *tempfile will be opened as stdout */
         if (open (*tempfile, O_WRONLY | O_APPEND | O_CREAT | O_EXCL, 0600) <
             0)
@@ -1743,11 +1745,11 @@ send_msg(const char *path, const char **args, const char *msg, char **tempfile)
       _exit (S_ERR);
     }
 
/* SendmailWait > 0: interrupt waitpid() after SendmailWait seconds
* SendmailWait = 0: wait forever
* SendmailWait < 0: don't wait
      */
-    if (SendmailWait > 0) {
+    if (MTransport.sendmail_wait > 0) {
       SigAlrm = 0;
       act.sa_handler = alarm_handler;
 #ifdef SA_INTERRUPT
@@ -1758,20 +1760,20 @@ send_msg(const char *path, const char **args, const char *msg, char **tempfile)
 #endif
       sigemptyset (&act.sa_mask);
       sigaction (SIGALRM, &act, &oldalrm);
-      alarm (SendmailWait);
+      alarm (MTransport.sendmail_wait);
     }
-    else if (SendmailWait < 0)
+    else if (MTransport.sendmail_wait < 0)
       _exit (0xff & EX_OK);
 
     if (waitpid (pid, &st, 0) > 0) {
       st = WIFEXITED (st) ? WEXITSTATUS (st) : S_ERR;
-      if (SendmailWait && st == (0xff & EX_OK)) {
+      if (MTransport.sendmail_wait && st == (0xff & EX_OK)) {
         unlink (*tempfile);     /* no longer needed */
         p_delete(tempfile);
       }
     } else {
-      st = (SendmailWait > 0 && errno == EINTR && SigAlrm) ? S_BKG : S_ERR;
-      if (SendmailWait > 0) {
+      st = (MTransport.sendmail_wait > 0 && errno == EINTR && SigAlrm) ? S_BKG : S_ERR;
+      if (MTransport.sendmail_wait > 0) {
         unlink (*tempfile);
         p_delete(tempfile);
       }
@@ -1831,31 +1833,29 @@ static int mutt_invoke_sendmail (address_t * from,        /* the sender */
                                  const char *msg,       /* file containing message */
                                  int eightbit)
 {                               /* message contains 8bit chars */
-  char *ps = NULL, *path = NULL, *s = NULL, *childout = NULL;
+  char cmd[LONG_STRING];
+  char *ps = NULL, *path = NULL, *childout = NULL;
   const char **args = NULL;
   ssize_t argslen = 0, argsmax = 0;
   int i;
 
 #ifdef USE_NNTP
   if (option (OPTNEWSSEND)) {
-    char cmd[LONG_STRING];
-
-    m_strformat(cmd, sizeof (cmd), NONULL (Inews), nntp_format_str, 0, 0);
+    m_strformat(cmd, sizeof(cmd), 0, Inews, nntp_format_str, 0, 0);
     if (m_strisempty(cmd)) {
       i = nntp_post (msg);
       unlink (msg);
       return i;
     }
-
-    s = m_strdup(cmd);
-  }
-  else
+  } else
 #endif
-    s = m_strdup(Sendmail);
+  {
+    m_strcpy(cmd, sizeof(cmd), MTransport.sendmail);
+  }
 
-  ps = s;
+  ps = cmd;
   i = 0;
-  while ((ps = strtok (ps, " "))) {
+  while ((ps = strtok(ps, " "))) {
     if (argslen == argsmax)
       p_realloc(&args, argsmax += 5);
 
@@ -1877,27 +1877,25 @@ static int mutt_invoke_sendmail (address_t * from,        /* the sender */
 #ifdef USE_NNTP
   if (!option (OPTNEWSSEND)) {
 #endif
-    if (eightbit && option (OPTUSE8BITMIME))
+    if (eightbit && MTransport.use_8bitmime)
       args = add_option(args, &argslen, &argsmax, "-B8BITMIME");
 
-    if (option (OPTENVFROM)) {
-      address_t *f = EnvFrom;
-      if (EnvFrom)
-        f = EnvFrom;
-      else if (from && !from->next)
+    if (MTransport.use_envelope_from) {
+      address_t *f = MTransport.envelope_from_address;
+      if (!f && from && !from->next)
         f = from;
       if (f) {
         args = add_option (args, &argslen, &argsmax, "-f");
         args = add_args (args, &argslen, &argsmax, f);
       }
     }
-    if (DsnNotify) {
+    if (MTransport.dsn_notify) {
       args = add_option (args, &argslen, &argsmax, "-N");
-      args = add_option (args, &argslen, &argsmax, DsnNotify);
+      args = add_option (args, &argslen, &argsmax, MTransport.dsn_notify);
     }
-    if (DsnReturn) {
+    if (MTransport.dsn_return) {
       args = add_option (args, &argslen, &argsmax, "-R");
-      args = add_option (args, &argslen, &argsmax, DsnReturn);
+      args = add_option (args, &argslen, &argsmax, MTransport.dsn_return);
     }
     args = add_option (args, &argslen, &argsmax, "--");
     args = add_args (args, &argslen, &argsmax, to);
@@ -1930,7 +1928,6 @@ static int mutt_invoke_sendmail (address_t * from,        /* the sender */
 
   p_delete(&childout);
   p_delete(&path);
-  p_delete(&s);
   p_delete(&args);
 
   if (i == (EX_OK & 0xff))
@@ -2040,7 +2037,7 @@ static int _mutt_bounce_message (FILE * fp, HEADER * h, address_t * to,
   if (!fp)
     fp = msg->fp;
 
-  f = m_tempfile(tempfile, sizeof(tempfile), NONULL(Tempdir), NULL);
+  f = m_tempfile(tempfile, sizeof(tempfile), NONULL(MCore.tmpdir), NULL);
   if (f) {
     int ch_flags = CH_XMIT | CH_NONEWLINE | CH_NOQFROM;
 
@@ -2130,7 +2127,7 @@ int mutt_write_fcc (const char *path, HEADER * hdr, const char *msgid,
    * the message body begins with "From "   
    */
   if (f.magic == M_MMDF || f.magic == M_MBOX) {
-    tempfp = m_tempfile(tempfile, sizeof(tempfile), NONULL(Tempdir), NULL);
+    tempfp = m_tempfile(tempfile, sizeof(tempfile), NONULL(MCore.tmpdir), NULL);
     if (!tempfp) {
       mutt_error(_("Could not create temporary file"));
       mx_close_mailbox (&f, NULL);
@@ -1743,11 +1745,11 @@ send_msg(const char *path, const char **args, const char *msg, char **tempfile)
     }
 
-    /* SendmailWait > 0: interrupt waitpid() after SendmailWait seconds
-     * SendmailWait = 0: wait forever
-     * SendmailWait < 0: don't wait
+    /* sendmail_wait > 0: interrupt waitpid() after sendmail_wait seconds
+     * sendmail_wait = 0: wait forever
+     * sendmail_wait < 0: don't wait
      */